#
# spec file for package lalframe
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# NEP 29: python36-numpy and co. in TW are no more
%define skip_python36 1
# Py2 support dropped by upstream
%define skip_python2 1

%define shlib lib%{name}14
# No support for octave >= 6
%bcond_with octave
Name:           lalframe
Version:        3.0.5
Release:        2.4
Summary:        LSC Algorithm Frame Library for gravitational wave data analysis
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Physics
URL:            https://wiki.ligo.org/Computing/LALSuite
Source:         https://software.igwn.org/sources/source/lalsuite/lalframe-%{version}.tar.xz
# PATCH-FIX-UPSTREAM
Patch0:         https://git.ligo.org/lscsoft/lalsuite/-/commit/9dba245ab3692ecf691247a442704f13c075ed34.patch#/lalframe-swig-stringval-not-value.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module lal >= 7.1.0}
BuildRequires:  %{python_module numpy >= 1.7}
BuildRequires:  %{python_module numpy-devel >= 1.7}
# python3-py - remove with next update -- https://git.ligo.org/lscsoft/lalsuite/-/merge_requests/2033
BuildRequires:  %{python_module py}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  swig
BuildRequires:  pkgconfig(framecppc)
BuildRequires:  pkgconfig(framel)
BuildRequires:  pkgconfig(lal) >= 6.21.0
Requires:       python-lal
Requires:       python-numpy >= 1.7
ExcludeArch:    %{ix86}
%if 0%{?suse_version} < 1550
BuildRequires:  python-xml
%endif
%if %{with octave}
BuildRequires:  octave-lal >= 7.1.0
BuildRequires:  pkgconfig(octave)
%endif
# SECTION For tests
BuildRequires:  %{python_module ligo-segments}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
The LSC Algorithm Frame Library for gravitational wave data analysis.

%package -n %{shlib}
Summary:        Shared library for LAL Frame
Group:          Productivity/Scientific/Physics

%description -n %{shlib}
This package contains the shared-object libraries needed to run applications
that use the LAL Frame library.

%package -n %{name}-devel
Summary:        Development files for LAL Frame
Group:          Development/Libraries/C and C++
Requires:       %{shlib} = %{version}
Requires:       pkgconfig(framecppc)
Requires:       pkgconfig(framel)
Requires:       pkgconfig(lal)

%description -n %{name}-devel
This package contains sources and header files needed to build applications
that use the LAL Frame library.

%if %{with octave}
%package -n octave-lalframe
Summary:        Octave bindings for LAL Frame
Group:          Productivity/Scientific/Physics
Requires:       octave-lal
%requires_eq    octave-cli

%description -n octave-lalframe
This package provides the necessary files for using LAL Frame with octave.
%endif

%prep
# Upstream commits are -p1 against the full lalsuite, but -p2 against individual lal* pkgs
%autosetup -p2

%build
%{python_expand # Necessary to run configure with multiple py3 flavours
export PYTHON=$python
mkdir ../${PYTHON}_build
cp -pr ./ ../${PYTHON}_build
pushd ../${PYTHON}_build
%configure \
  %{?with_octave:--enable-swig-octave} \
  %{!?with_octave:--disable-swig-octave}
%make_build
popd
}

%install
%{python_expand # py2 and py3 make_install
export PYTHON=$python
pushd ../${PYTHON}_build
%make_install
popd
}

# SECTION EXPORT LAL SPECIFIC ENV VARIABLES
# We do not use upstream's env files because they also set more generic
# variables (e.g. PATH) which may ruin setups

# NUKE UPSTREAM ENV SCRIPTS
rm %{buildroot}%{_sysconfdir}/%{name}-user-env.*

cat << EOF >> %{name}.sh
export LALFRAME_PREFIX=%{_prefix}
export LALFRAME_DATADIR=%{_datadir}/%{name}
EOF

cat << EOF >> %{name}.csh
setenv LALFRAME_PREFIX "%{_prefix}"
setenv LALFRAME_DATADIR "%{_datadir}/%{name}"
EOF

cat << EOF >> %{name}.fish
set LALFRAME_PREFIX (echo "%{_prefix}" | %{_bindir}/sed -e 's| |:|g;')
set LALFRAME_DATADIR (echo "%{_datadir}/%{name}" | %{_bindir}/sed -e 's| |:|g;')
EOF

install -D -m0644 %{name}.sh %{buildroot}%{_sysconfdir}/profile.d/%{name}.sh
install -D -m0644 %{name}.csh %{buildroot}%{_sysconfdir}/profile.d/%{name}.csh
install -D -m0644 %{name}.fish %{buildroot}%{_sysconfdir}/profile.d/%{name}.fish

# /SECTION

# SECTION REMOVE STATIC LIB AND LIBTOOL ARCHIVE
find %{buildroot}%{_libdir}/ -name "*.a" -delete -print
find %{buildroot} -type f -name "*.la" -delete -print
# /SECTION

%python_expand %fdupes %{buildroot}%{$python_sitearch}/%{name}/

%check
%{python_expand # check all flavors
export PYTHON=$python
pushd ../${PYTHON}_build
%make_build check
}

%post -n %{shlib} -p /sbin/ldconfig
%postun -n %{shlib} -p /sbin/ldconfig

%files -n %{shlib}
%{_libdir}/*.so.*

%files -n %{name}-devel
%doc AUTHORS README.md
%license COPYING
%{_bindir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/*
%{_mandir}/man1/*.1%{?ext_man}
%config %{_sysconfdir}/profile.d/%{name}.*

%if %{with octave}
%files -n octave-%{name}
%dir %{_libdir}/octave/*/site
%dir %{_libdir}/octave/*/site/oct
%dir %{_libdir}/octave/*/site/oct/*
%{_libdir}/octave/*/site/oct/*/*.oct
%endif

%files %{python_files}
%{python_sitearch}/lalframe/

%changelog
* Mon Dec  2 2024 Atri Bhattacharya <badshah400@gmail.com>
- Add lalframe-swig-stringval-not-value.patch: For compatibility
  with swig 4.3.0, prefer 'stringval' before 'value' attribute
  (upstream commit 9dba245a).
* Mon Nov 18 2024 Atri Bhattacharya <badshah400@gmail.com>
- Fix use of %%requires_eq with respect to octave.
* Wed Sep 11 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.5:
  * No release notes.
* Sat Jul 20 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.4:
  * No release notes.
* Mon Jan 22 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.3:
  * No release notes.
* Tue May 23 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.1:
  * No release notes.
- Update shlib package name in keeping with upstream so version.
* Sun Feb 12 2023 Atri Bhattacharya <badshah400@gmail.com>
- Add python-py BuildRequires to fix tests that fail due to "No
  module named 'py._path'" errors.
* Fri Aug 19 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.1:
  * No release notes.
- Update so version to match upstream.
- Update source URL.
* Sun Jan  2 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.6.0:
  * No release notes.
- Drop support for python2 in keeping with upstream.
* Fri Feb 26 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.4:
  * No release notes.
* Fri Feb 12 2021 Ben Greiner <code@bnavigator.de>
- Update to version 1.5.3:
  * No release notes.
- Skip python36 build because python36-numpy in TW is no more
  (NEP29)
* Thu Jan 21 2021 Atri Bhattacharya <badshah400@gmail.com>
- Fix up dependency for tests and the %%check section running the
  tests for mutli-versioned python.
* Mon Dec 21 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.2:
  * No release notes.
- Disable octave bindings: octave >= 6 unsupported.
* Sun Oct 25 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update URL.
- Specfile cleanups using spec-cleaner.
* Fri Oct 23 2020 Atri Bhattacharya <badshah400@gmail.com>
- Drop redundant build/runtime dependencies:
  * libframe-devel: superseded by framel-devel.
  * ldas-tools-framecpp-devel is identical to
    pkgconfig(framecppc).
* Sat Aug 15 2020 Atri Bhattacharya <badshah400@gmail.com>
- Implement tests as part of %%check; additionally needs
  BuildRequires: python3-pytest.
- ExcludeArch 32-bit, as tests fail and upstream confirms that it
  is not supported
  (https://git.ligo.org/lscsoft/lalsuite/-/issues/371).
* Mon Jul  6 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.1
  * No release notes.
- New BuildRequires: pkgconfig(framel), pkgconfig(framecppc).
- Drop lalframe-build-octave44-with-swig3.patch: Incorporated
  upstream (also drop BuildRequires: libtool and the command
  autoreconf before configure).
- Re-enable octave bindings, fixed upstream.
* Wed Jul  1 2020 Atri Bhattacharya <badshah400@gmail.com>
- Disable octave support as compilation error with current swig.
* Mon May 11 2020 Atri Bhattacharya <badshah400@gmail.com>
- Improve Summary.
* Wed Apr 22 2020 Atri Bhattacharya <badshah400@gmail.com>
- BuildRequires: python-xml only for openSUSE <= 15.2 since
  python2 is disabled for newer openSUSE.
* Sun Feb  2 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.0:
  * O3b release
- Rebase lalframe-build-octave44-with-swig3.patch for updated
  version.
* Mon Sep 30 2019 Atri Bhattacharya <badshah400@gmail.com>
- Build for python2 and python3
* Mon Jul 22 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.4.5
  * O3 release.
- Rebase lal-frame-build-octave44-with-swig3.patch to conform to
  upstream's reworking for swig and octave version tests.
* Fri Feb  8 2019 badshah400@gmail.com
- Switch builds to python2; add python-xml BuildRequires.
* Thu Feb  7 2019 badshah400@gmail.com
- Update Requires for octave-%%{name}.
* Thu Feb  7 2019 badshah400@gmail.com
- Update Requires for -devel pkg and python modules.
* Wed Feb  6 2019 badshah400@gmail.com
- Add lalframe-build-octave44-with-swig3.patch: allow building
  octave bindings with swig 3.0.x rather than requiring swig 4.x.
* Wed Nov 28 2018 badshah400@gmail.com
- Initial Package.
